@@ -62,7 +62,7 @@
 
 /* Macro to strip 'const' without triggering a compiler warning.
    Use it for APIs that do not or cannot support the const qualifier. */
-#ifdef HAVE_STDINT_H
+#ifdef HAVE_UINTPTR_T
 #  define CURL_UNCONST(p) ((void *)(uintptr_t)(const void *)(p))
 #else
 #  define CURL_UNCONST(p) ((void *)(p))  /* Fall back to simple cast */
